@@ -14,20 +14,80 @@ Available Commands:
   yolo4r help       Show this help menu.
 
 ----------------------------------------------
-Command-Specific Help:
-  yolo4r train --help
-  yolo4r detect --help
 
+Command Specific Help:
+  yolo4r train help
+  yolo4r detect help
+
+----------------------------------------------
+          
 Examples:
-  yolo4r train -m yolo11n.pt -a custom_arch.yaml --dataset birds
-  yolo4r train --scratch -a bird_model.yaml
-  yolo4r detect --sources usb0 usb1 trailcam.mp4
-  yolo4r detect trailcam.mp4
+  yolo4r train model=yolo11n architecture=custom_arch dataset=birds
+  yolo4r train architecture=yolo12
+  yolo4r train model=yolov8x name="best run ever!!" test
+  yolo4r detect sources=usb0 usb1 usb2
+  yolo4r detect test trailcam.mp4 trailcam2.mov
 
 YOLO4r Documentation & Support:
-  https://github.com/yourproject/yolo4r
+  https://github.com/kgoertle/yolo4r
 """)
 
+def expand_key_value_args(argv):
+    expanded = []
+
+    mappings = {
+        "name": "--name",
+        "run": "--name",
+        "run_name": "--name",
+
+        "model": "--model",
+        "weights": "--model",
+
+        "arch": "--arch",
+        "architecture": "--arch",
+        "backbone": "--arch",
+
+        "data": "--dataset",
+        "dataset": "--dataset",
+
+        "labelstudio": "--labelstudio",
+        "project": "--labelstudio",
+
+        "sources": "--sources",
+        "source": "--sources",
+
+        "test": "--test",
+    }
+
+    boolean_true = {"1", "true", "yes", "on", ""}
+
+    for arg in argv:
+
+        # ---------- special case: plain "test" ----------
+        if arg.lower() == "test":
+            expanded.append("--test")
+            continue
+
+        # ---------- key=value pattern ----------
+        if "=" in arg:
+            key, value = arg.split("=", 1)
+            key = key.lower()
+
+            # special case: test=true / test=1
+            if key == "test":
+                if value.lower() in boolean_true:
+                    expanded.append("--test")
+                continue
+
+            if key in mappings:
+                expanded.append(mappings[key])
+                expanded.append(value)
+                continue
+
+        expanded.append(arg)
+
+    return expanded
+
 def main():
     parser = argparse.ArgumentParser(
         prog="yolo4r",
@@ -56,6 +116,9 @@ def main():
     # ---- Parse command (not sub-arguments) ----
     args, unknown = parser.parse_known_args()
 
+    # Expand key=value into standard flags
+    unknown = expand_key_value_args(unknown)
+
     # ROUTING
     if args.func == "train":
         from .train import main as train_main
