@@ -6,7 +6,7 @@ import numpy as np
 from ultralytics import YOLO
 
 # ----------- UTILITIES ---------------
-from .utils.detect.paths import get_runs_dir, get_output_folder, get_model_data_yaml
+from .utils.paths import get_runs_dir, get_output_folder, get_model_data_yaml
 from .utils.detect.arg_parser import parse_arguments
 from .utils.detect.printer import Printer
 from .utils.detect.measurements import MeasurementConfig, Counter, Interactions, Aggregator, compute_counts_from_boxes
@@ -17,6 +17,7 @@ from .utils.detect.video_metadata import extract_video_metadata, parse_creation_
 stop_event = threading.Event()
 IS_MAC = platform.system() == "Darwin"
 IS_LINUX = platform.system() == "Linux"
+IS_PI = IS_LINUX and ("arm" in platform.machine() or "aarch64" in platform.machine())
 
 # ----------- VIDEO PROCESSOR -----------
 class VideoProcessor:
