@@ -78,12 +78,6 @@ def _save_model_config():
 
 # ---------- RELOAD EXISTING MODEL CONFIG ----------
 def _reload_model_config(printer=None):
-    """
-    Reload the model-specific classes_config.yaml.
-    If the YAML is corrupted or unreadable, show a clean error message,
-    return False, and allow fallback to data.yaml.
-    """
-
     if not CURRENT_MODEL_CONFIG or not CURRENT_MODEL_CONFIG.exists():
         return False
 
